@@ -2,33 +2,31 @@
 #
 #   file: Dist/Zilla/Role/ErrorLogger.pm
 #
-
-#pod =encoding UTF-8
-#pod
-#pod =head1 COPYRIGHT AND LICENSE
-#pod
-#pod Copyright © 2015 Van de Bugger
-#pod
-#pod This file is part of perl-Dist-Zilla-Role-ErrorLogger.
-#pod
-#pod perl-Dist-Zilla-Role-ErrorLogger is free software: you can redistribute it and/or modify it
-#pod under the terms of the GNU General Public License as published by the Free Software Foundation,
-#pod either version 3 of the License, or (at your option) any later version.
-#pod
-#pod perl-Dist-Zilla-Role-ErrorLogger is distributed in the hope that it will be useful, but WITHOUT
-#pod ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR
-#pod PURPOSE. See the GNU General Public License for more details.
-#pod
-#pod You should have received a copy of the GNU General Public License along with
-#pod perl-Dist-Zilla-Role-ErrorLogger. If not, see <http://www.gnu.org/licenses/>.
-#pod
-#pod =cut
-
+#   Copyright © 2015 Van de Bugger
+#
+#   This file is part of perl-Dist-Zilla-Role-ErrorLogger.
+#
+#   perl-Dist-Zilla-Role-ErrorLogger is free software: you can redistribute it and/or modify it
+#   under the terms of the GNU General Public License as published by the Free Software Foundation,
+#   either version 3 of the License, or (at your option) any later version.
+#
+#   perl-Dist-Zilla-Role-ErrorLogger is distributed in the hope that it will be useful, but WITHOUT
+#   ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR
+#   PURPOSE. See the GNU General Public License for more details.
+#
+#   You should have received a copy of the GNU General Public License along with
+#   perl-Dist-Zilla-Role-ErrorLogger. If not, see <http://www.gnu.org/licenses/>.
+#
 #   - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
 
 #pod =for :this This is C<Dist::Zilla::Role::ErrorLogger> role documentation. Read this if you want to
 #pod have error logging capabilities in your Dist::Zilla plugin.
 #pod
+#pod =for test_synopsis
+#pod my ( $cond, $file );
+#pod sub Dist::Zilla::Plugin::YourPlugin::do_something;
+#pod sub Dist::Zilla::Plugin::YourPlugin::do_something_else;
+#pod
 #pod =head1 SYNOPSIS
 #pod
 #pod     package Dist::Zilla::Plugin::YourPlugin;
@@ -39,20 +37,21 @@
 #pod
 #pod     sub method {
 #pod         my $self = shift( @_ );
-#pod         …
-#pod         if ( … ) { $self->log_error( 'error message' ); };
+#pod
+#pod         if ( $cond ) { $self->log_error( 'error message' ); };
+#pod
 #pod         do_something or $self->log_error( 'another error message' );
-#pod         …
-#pod         while ( … ) {
+#pod
+#pod         while ( $cond ) {
 #pod             do_something_else or $self->log_error( 'error message' ) and next;
 #pod         };
-#pod         …
+#pod
 #pod         $self->log_errors_in_file(
 #pod             $file,
 #pod             1 => 'error message',           # Error at file line 1.
 #pod             5 => 'another error message',   # Error at file line 5.
 #pod         );
-#pod         …
+#pod
 #pod         $self->abort_if_error( 'errors found' );
 #pod     };
 #pod
@@ -81,7 +80,7 @@ use Moose::Role;
 use namespace::autoclean;
 
 # ABSTRACT: Have error logging capabilities in your Dist::Zilla plugin
-our $VERSION = 'v0.7.0'; # VERSION
+our $VERSION = 'v0.8.0'; # VERSION
 
 requires qw{ log };
 
@@ -188,8 +187,9 @@ sub abort_if_error {                    ## no critic ( RequireArgUnpacking )
 #pod
 #pod     $self->log_errors_in_file(
 #pod         $file,
-#pod         $linenum0 => $message0,
 #pod         $linenum1 => $message1,
+#pod         $linenum2 => $message2,
+#pod         $linenum3 => [ $message3a, $message3b, ... ],
 #pod         ...
 #pod     );
 #pod
@@ -197,9 +197,10 @@ sub abort_if_error {                    ## no critic ( RequireArgUnpacking )
 #pod C<Dist::Zilla::File::InMemory>, or does role C<Dist::Zilla::Role::File>).
 #pod
 #pod Errors are specified by pairs C<< $linenum => $message >>, where C<$linenum> is a number of problem
-#pod line (one-based), and C<$message> is an error message. Order of errors does not matter usually.
-#pod However, if messages are associated with the same line, they will be printed in order of appearance
-#pod (Yes, a line may have associated more than one error message.)
+#pod line (one-based), and C<$message> is an error message (C<Str>) or array of messages
+#pod (C<ArrayRef[Str]>). Order of errors does not matter usually. However, if errors are associated with
+#pod the same line (the same line number may appear multiple times), they will be printed in order of
+#pod appearance.
 #pod
 #pod Zero or negative line numbers, or line numbers beyond the last line are invalid. Messages
 #pod associated with invalid line numbers are reported in unspecified way.
@@ -230,17 +231,17 @@ sub log_errors_in_file {
     my %errors;     # Key is line number, value is arrayref to error messages.
     my %invalid;    # The same but for invalid line numbers.
     while ( @errors ) {
-        my ( $n, $message ) = splice( @errors, 0, 2 );
-        if ( 1<= $n and $n <= @$text ) {
+        my ( $n, $msg ) = splice( @errors, 0, 2 );
+        if ( 1 <= $n and $n <= @$text ) {
             my $ctx = 2; # TODO: Parametrize it?
             for my $k ( max( $n - $ctx, 1 ) .. min( $n + $ctx, @$text + 0 ) ) {
                 if ( not $errors{ $k } ) {
                     $errors{ $k } = [];
                 };
             };
-            push( @{ $errors{ $n } }, $message );
+            push( @{ $errors{ $n } }, ref( $msg ) ? @$msg : $msg );
         } else {
-            push( @{ $invalid{ $n } }, $message );
+            push( @{ $invalid{ $n } }, ref( $msg ) ? @$msg : $msg );
         };
     };
 
@@ -338,6 +339,17 @@ sub log_errors_in_file {
 #pod = L<Log::Dispatchouli>
 #pod = L<String::Flogger>
 #pod
+#pod =head1 COPYRIGHT AND LICENSE
+#pod
+#pod Copyright (C) 2015 Van de Bugger
+#pod
+#pod License GPLv3+: The GNU General Public License version 3 or later
+#pod <http://www.gnu.org/licenses/gpl-3.0.txt>.
+#pod
+#pod This is free software: you are free to change and redistribute it. There is
+#pod NO WARRANTY, to the extent permitted by law.
+#pod
+#pod
 #pod =cut
 
 # doc/what.pod #
@@ -418,7 +430,7 @@ Dist::Zilla::Role::ErrorLogger - Have error logging capabilities in your Dist::Z
 
 =head1 VERSION
 
-Version v0.7.0, released on 2015-09-17 18:18 UTC.
+Version v0.8.0, released on 2015-10-24 17:27 UTC.
 
 =head1 WHAT?
 
@@ -438,20 +450,21 @@ have error logging capabilities in your Dist::Zilla plugin.
 
     sub method {
         my $self = shift( @_ );
-        …
-        if ( … ) { $self->log_error( 'error message' ); };
+
+        if ( $cond ) { $self->log_error( 'error message' ); };
+
         do_something or $self->log_error( 'another error message' );
-        …
-        while ( … ) {
+
+        while ( $cond ) {
             do_something_else or $self->log_error( 'error message' ) and next;
         };
-        …
+
         $self->log_errors_in_file(
             $file,
             1 => 'error message',           # Error at file line 1.
             5 => 'another error message',   # Error at file line 5.
         );
-        …
+
         $self->abort_if_error( 'errors found' );
     };
 
@@ -517,8 +530,9 @@ line).
 
     $self->log_errors_in_file(
         $file,
-        $linenum0 => $message0,
         $linenum1 => $message1,
+        $linenum2 => $message2,
+        $linenum3 => [ $message3a, $message3b, ... ],
         ...
     );
 
@@ -526,9 +540,10 @@ C<$file> should be a C<Dist::Zilla> file (e. g. C<Dist::Zilla::File::OnDisk>,
 C<Dist::Zilla::File::InMemory>, or does role C<Dist::Zilla::Role::File>).
 
 Errors are specified by pairs C<< $linenum => $message >>, where C<$linenum> is a number of problem
-line (one-based), and C<$message> is an error message. Order of errors does not matter usually.
-However, if messages are associated with the same line, they will be printed in order of appearance
-(Yes, a line may have associated more than one error message.)
+line (one-based), and C<$message> is an error message (C<Str>) or array of messages
+(C<ArrayRef[Str]>). Order of errors does not matter usually. However, if errors are associated with
+the same line (the same line number may appear multiple times), they will be printed in order of
+appearance.
 
 Zero or negative line numbers, or line numbers beyond the last line are invalid. Messages
 associated with invalid line numbers are reported in unspecified way.
@@ -583,6 +598,10 @@ C<Dist-Zilla-Role-ErrorLogger> role automates it, making plugin code shorter and
     …
     $self->abort_if_error();
 
+=for test_synopsis my ( $cond, $file );
+sub Dist::Zilla::Plugin::YourPlugin::do_something;
+sub Dist::Zilla::Plugin::YourPlugin::do_something_else;
+
 =head1 NOTES
 
 All the methods defined in the role log items through the C<log> method. C<Dist::Zilla> takes this
@@ -629,19 +648,12 @@ Van de Bugger <van.de.bugger@gmail.com>
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright © 2015 Van de Bugger
+Copyright (C) 2015 Van de Bugger
 
-This file is part of perl-Dist-Zilla-Role-ErrorLogger.
+License GPLv3+: The GNU General Public License version 3 or later
+<http://www.gnu.org/licenses/gpl-3.0.txt>.
 
-perl-Dist-Zilla-Role-ErrorLogger is free software: you can redistribute it and/or modify it
-under the terms of the GNU General Public License as published by the Free Software Foundation,
-either version 3 of the License, or (at your option) any later version.
-
-perl-Dist-Zilla-Role-ErrorLogger is distributed in the hope that it will be useful, but WITHOUT
-ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR
-PURPOSE. See the GNU General Public License for more details.
-
-You should have received a copy of the GNU General Public License along with
-perl-Dist-Zilla-Role-ErrorLogger. If not, see <http://www.gnu.org/licenses/>.
+This is free software: you are free to change and redistribute it. There is
+NO WARRANTY, to the extent permitted by law.
 
 =cut
